@@ -56,7 +56,7 @@
 #' @export
 binned_residuals <- function(model, term = NULL, n_bins = NULL, ...) {
   fv <- stats::fitted(model)
-  mf <- insight::get_data(model)
+  mf <- insight::get_data(model, verbose = FALSE)
 
   if (is.null(term)) {
     pred <- fv
@@ -122,12 +122,30 @@ print.binned_residuals <- function(x, ...) {
   resid_ok <- attributes(x)$resid_ok
 
   if (!is.null(resid_ok)) {
-    if (resid_ok < .8) {
-      insight::print_color(sprintf("Warning: Probably bad model fit. Only about %g%% of the residuals are inside the error bounds.\n", round(100 * resid_ok)), "red")
-    } else if (resid_ok < .95) {
-      insight::print_color(sprintf("Warning: About %g%% of the residuals are inside the error bounds (~95%% or higher would be good).\n", round(100 * resid_ok)), "yellow")
+    if (resid_ok < 0.8) {
+      insight::print_color(
+        sprintf(
+          "Warning: Probably bad model fit. Only about %g%% of the residuals are inside the error bounds.\n",
+          round(100 * resid_ok)
+        ),
+        "red"
+      )
+    } else if (resid_ok < 0.95) {
+      insight::print_color(
+        sprintf(
+          "Warning: About %g%% of the residuals are inside the error bounds (~95%% or higher would be good).\n",
+          round(100 * resid_ok)
+        ),
+        "yellow"
+      )
     } else {
-      insight::print_color(sprintf("Ok: About %g%% of the residuals are inside the error bounds.\n", round(100 * resid_ok)), "green")
+      insight::print_color(
+        sprintf(
+          "Ok: About %g%% of the residuals are inside the error bounds.\n",
+          round(100 * resid_ok)
+        ),
+        "green"
+      )
     }
   }
 }
