@@ -50,16 +50,74 @@
 #'   A more advanced model-check for Bayesian models will be implemented at a
 #'   later stage.
 #'
+#' @section Posterior Predictive Checks:
+#' Posterior predictive checks can be used to look for systematic discrepancies
+#' between real and simulated data. It helps to see whether the type of model
+#' (distributional family) fits well to the data. See [`check_predictions()`]
+#' for further details.
+#'
 #' @section Linearity Assumption:
 #' The plot **Linearity** checks the assumption of linear relationship.
 #' However, the spread of dots also indicate possible heteroscedasticity (i.e.
-#' non-constant variance); hence, the alias `"ncv"` for this plot.
+#' non-constant variance, hence, the alias `"ncv"` for this plot), thus it shows
+#' if residuals have non-linear patterns. This plot helps to see whether
+#' predictors may have a non-linear relationship with the outcome, in which case
+#' the reference line may roughly indicate that relationship. A straight and
+#' horizontal line indicates that the model specification seems to be ok. But
+#' for instance, if the line would be U-shaped, some of the predictors probably
+#' should better be modeled as quadratic term. See [`check_heteroscedasticity()`]
+#' for further details.
+#'
 #' **Some caution is needed** when interpreting these plots. Although these
-#' plots are helpful to check model assumptions, they do not necessarily
-#' indicate so-called "lack of fit", e.g. missed non-linear relationships or
-#' interactions. Thus, it is always recommended to also look at
+#' plots are helpful to check model assumptions, they do not necessarily indicate
+#' so-called "lack of fit", e.g. missed non-linear relationships or interactions.
+#' Thus, it is always recommended to also look at
 #' [effect plots, including partial residuals](https://strengejacke.github.io/ggeffects/articles/introduction_partial_residuals.html).
 #'
+#' @section Homogeneity of Variance:
+#' This plot checks the assumption of equal variance (homoscedasticity). The
+#' desired pattern would be that dots spread equally above and below a straight,
+#' horizontal line and show no apparent deviation.
+#'
+#' @section Influential Observations:
+#' This plot is used to identify influential observations. If any points in this
+#' plot fall outside of Cook’s distance (the dashed lines) then it is considered
+#' an influential observation. See [`check_outliers()`] for further details.
+#'
+#' @section Multicollinearity:
+#' This plot checks for potential collinearity among predictors. In a nutshell,
+#' multicollinearity means that once you know the effect of one predictor, the
+#' value of knowing the other predictor is rather low. Multicollinearity might
+#' arise when a third, unobserved variable has a causal effect on each of the
+#' two predictors that are associated with the outcome. In such cases, the actual
+#' relationship that matters would be the association between the unobserved
+#' variable and the outcome. See [`check_collinearity()`] for further details.
+#'
+#' @section Normality of Residuals:
+#' This plot is used to determine if the residuals of the regression model are
+#' normally distributed. Usually, dots should fall along the line. If there is
+#' some deviation (mostly at the tails), this indicates that the model doesn't
+#' predict the outcome well for that range that shows larger deviations from
+#' the line. For generalized linear models, a half-normal Q-Q plot of the
+#' absolute value of the standardized deviance residuals is shown, however, the
+#' interpretation of the plot remains the same. See [`check_normality()`] for
+#' further details.
+#'
+#' @section Overdispersion:
+#' For count models, an *overdispersion plot* is shown. Overdispersion occurs
+#' when the observed variance is higher than the variance of a theoretical model.
+#' For Poisson models, variance increases with the mean and, therefore, variance
+#' usually (roughly) equals the mean value. If the variance is much higher,
+#' the data are "overdispersed". See [`check_overdispersion()`] for further
+#' details.
+#'
+#' @section Binned Residuals:
+#' For models from binomial families, a *binned residuals plot* is shown.
+#' Binned residual plots are achieved by cutting the the data into bins and then
+#' plotting the average residual versus the average fitted value for each bin.
+#' If the model were true, one would expect about 95% of the residuals to fall
+#' inside the error bounds. See [`binned_residuals()`] for further details.
+#'
 #' @section Residuals for (Generalized) Linear Models:
 #' Plots that check the normality of residuals (QQ-plot) or the homogeneity of
 #' variance use standardized Pearson's residuals for generalized linear models,
@@ -76,6 +134,8 @@
 #' look at the `check` argument and see if some of the model checks could be
 #' skipped, which also increases performance.
 #'
+#' @family functions to check model assumptions and and assess model quality
+#'
 #' @examples
 #' \dontrun{
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
@@ -104,11 +164,11 @@ check_model <- function(x, ...) {
 #' @export
 check_model.default <- function(x,
                                 dot_size = 2,
-                                line_size = .8,
+                                line_size = 0.8,
                                 panel = TRUE,
                                 check = "all",
-                                alpha = .2,
-                                dot_alpha = .8,
+                                alpha = 0.2,
+                                dot_alpha = 0.8,
                                 colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
                                 theme = "see::theme_lucid",
                                 detrend = FALSE,
@@ -143,7 +203,7 @@ check_model.default <- function(x,
 
   # set default for show_dots, based on "model size"
   if (is.null(show_dots)) {
-    n <- tryCatch(insight::n_obs(x), error = function(e) NULL)
+    n <- .safe(insight::n_obs(x))
     show_dots <- is.null(n) || n <= 1e5
   }
 
@@ -187,11 +247,11 @@ plot.check_model <- function(x, ...) {
 #' @export
 check_model.stanreg <- function(x,
                                 dot_size = 2,
-                                line_size = .8,
+                                line_size = 0.8,
                                 panel = TRUE,
                                 check = "all",
-                                alpha = .2,
-                                dot_alpha = .8,
+                                alpha = 0.2,
+                                dot_alpha = 0.8,
                                 colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
                                 theme = "see::theme_lucid",
                                 detrend = FALSE,
@@ -222,11 +282,11 @@ check_model.brmsfit <- check_model.stanreg
 #' @export
 check_model.model_fit <- function(x,
                                   dot_size = 2,
-                                  line_size = .8,
+                                  line_size = 0.8,
                                   panel = TRUE,
                                   check = "all",
-                                  alpha = .2,
-                                  dot_alpha = .8,
+                                  alpha = 0.2,
+                                  dot_alpha = 0.8,
                                   colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
                                   theme = "see::theme_lucid",
                                   detrend = FALSE,
@@ -270,7 +330,7 @@ check_model.model_fit <- function(x,
     threshold <- NULL
   }
   dat$INFLUENTIAL <- .influential_obs(model, threshold = threshold)
-  dat$PP_CHECK <- tryCatch(check_predictions(model), error = function(e) NULL)
+  dat$PP_CHECK <- .safe(check_predictions(model))
 
   dat <- insight::compact_list(dat)
   class(dat) <- c("check_model", "see_check_model")
@@ -295,7 +355,7 @@ check_model.model_fit <- function(x,
     threshold <- NULL
   }
   dat$INFLUENTIAL <- .influential_obs(model, threshold = threshold)
-  dat$PP_CHECK <- tryCatch(check_predictions(model), error = function(e) NULL)
+  dat$PP_CHECK <- .safe(check_predictions(model))
   if (isTRUE(model_info$is_binomial)) {
     dat$BINNED_RESID <- binned_residuals(model)
   }
