@@ -13,16 +13,19 @@
 #'   significant deviation from normal distribution.
 #'
 #' @note For mixed-effects models, studentized residuals, and *not*
-#'   standardized residuals, are used for the test. There is also a
-#'   [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
-#'    implemented in the
-#'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' standardized residuals, are used for the test. There is also a
+#' [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
+#'  implemented in the [**see**-package](https://easystats.github.io/see/).
 #'
 #' @details `check_normality()` calls `stats::shapiro.test` and checks the
-#' standardized residuals (or Studentized residuals for mixed models) for
+#' standardized residuals (or studentized residuals for mixed models) for
 #' normal distribution. Note that this formal test almost always yields
 #' significant results for the distribution of residuals and visual inspection
-#' (e.g. Q-Q plots) are preferable.
+#' (e.g. Q-Q plots) are preferable. For generalized linear models, no formal
+#' statistical test is carried out. Rather, there's only a `plot()` method for
+#' GLMs. This plot shows a half-normal Q-Q plot of the absolute value of the
+#' standardized deviance residuals is shown (being in line with changes in
+#' `plot.lm()` for R 4.3+).
 #'
 #' @examples
 #' m <<- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
@@ -56,7 +59,7 @@ check_normality.default <- function(x, ...) {
 
   if (!insight::model_info(x)$is_linear) {
     insight::format_alert(
-      "Checking normality of residuals is only useful an appropriate assumption for linear models."
+      "Checking normality of residuals is only appropriate for linear models."
     )
     return(NULL)
   }
@@ -72,10 +75,57 @@ check_normality.default <- function(x, ...) {
   p.val
 }
 
+# glm ---------------
+
+#' @export
+check_normality.glm <- function(x, ...) {
+  out <- 1
+  attr(out, "data") <- x
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+  attr(out, "effects") <- "fixed"
+  attr(out, "model_info") <- insight::model_info(x)
+  class(out) <- unique(c("check_normality", "see_check_normality", class(out)))
+
+  insight::format_alert(
+    "There's no formal statistical test for normality for generalized linear model.",
+    "Please use `plot()` on the return value of this function: `plot(check_normality(model))`"
+  )
+  invisible(out)
+}
+
+# numeric -------------------
+
+#' @export
+check_normality.numeric <- function(x, ...) {
+  # check for normality of residuals
+  p.val <- .check_normality(x, NULL, type = "raw")
+
+  attr(p.val, "data") <- x
+  attr(p.val, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(p.val, "effects") <- "fixed"
+  class(p.val) <- unique(c("check_normality", "see_check_normality", "check_normality_numeric", class(p.val)))
+
+  p.val
+}
 
 
 # methods ----------------------
 
+
+#' @importFrom stats residuals
+#' @export
+residuals.check_normality_numeric <- function(object, ...) {
+  attr(object, "data")
+}
+
+
+#' @importFrom stats rstudent
+#' @export
+rstudent.check_normality_numeric <- function(model, ...) {
+  attr(model, "data")
+}
+
+
 #' @export
 plot.check_normality <- function(x, ...) {
   insight::check_if_installed("see", "for residual plots")
@@ -132,7 +182,7 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
   # valid model?
   if (!info$is_linear && effects == "fixed") {
     insight::format_alert(
-      "Checking normality of residuals is only useful an appropriate assumption for linear models."
+      "Checking normality of residuals is only appropriate for linear models."
     )
     return(NULL)
   }
@@ -155,8 +205,7 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
       }
     )
 
-    p.val <- c()
-    re_groups <- c()
+    p.val <- re_groups <- NULL
 
     if (!is.null(re)) {
       for (i in names(re)) {
@@ -212,18 +261,13 @@ check_normality.BFBayesFactor <- check_normality.afex_aov
 # helper ---------------------
 
 .check_normality <- function(x, model, type = "residuals") {
-  ts <- tryCatch(
-    {
-      if (length(x) >= 5000) {
-        suppressWarnings(stats::ks.test(x, y = "pnorm", alternative = "two.sided"))
-      } else {
-        stats::shapiro.test(x)
-      }
-    },
-    error = function(e) {
-      NULL
+  ts <- .safe({
+    if (length(x) >= 5000) {
+      suppressWarnings(stats::ks.test(x, y = "pnorm", alternative = "two.sided"))
+    } else {
+      stats::shapiro.test(x)
     }
-  )
+  })
 
   if (is.null(ts)) {
     insight::print_color(
